@@ -4,28 +4,22 @@
 ( cd opt/kde/share/doc/HTML/es/kdf ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kdm ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/kit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/kit ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kpf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kpf ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/amor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/amor ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/karm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/karm ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/kate ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/kate ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kdat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kdat ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kdvi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kdvi ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/kgeo ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/kgeo ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kmid ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kmid ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kmix ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kmix ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kodo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kodo ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/kpat ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/kpat ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/korn ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kppp ; rm -rf common )
@@ -34,6 +28,8 @@
 ( cd opt/kde/share/doc/HTML/es/kscd ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/ksim ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/ksim ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/lisa ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/lisa ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kalzium ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kalzium ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/katomic ; rm -rf common )
@@ -70,10 +66,8 @@
 ( cd opt/kde/share/doc/HTML/es/kiten ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kjots ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kjots ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/kmidi ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/kmidi ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/kmoon ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/kmoon ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kmail ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kmail ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/knode ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/knode ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kooka ; rm -rf common )
@@ -100,20 +94,20 @@
 ( cd opt/kde/share/doc/HTML/es/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kompare ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kontact ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kontact ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/konsole ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/konsolekalendar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kpackage ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/khelpcenter/faq ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/khelpcenter/quickstart ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/khelpcenter/glossary ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/khelpcenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/khelpcenter/userguide ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/khelpcenter/visualdict ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kshisen ; rm -rf common )
@@ -124,16 +118,18 @@
 ( cd opt/kde/share/doc/HTML/es/konquest ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kverbos ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kwallet ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kwallet ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kweather ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kwuftpd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kwifimanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kmenuedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/kioslave ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/kioslave ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/flashkard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/flashkard ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kbackgammon ; rm -rf common )
@@ -180,6 +176,8 @@
 ( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/es/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/es/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/es/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/es/common ; rm -rf doxygen.css )
@@ -194,12 +192,16 @@
 ( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/es/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/es/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/es/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/es/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/es/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/es/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/es/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/es/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/es/common ; rm -rf fdl-license.html )
@@ -336,24 +338,20 @@
 ( cd opt/kde/share/doc/HTML/es/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/artsbuilder ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/kbabel ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/kbabel ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kalarm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kalarm ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kamera ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kamera ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/kdeprint ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/kdeprint ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kasteroids ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kasteroids ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/keduca ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/keduca ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kgamma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kgamma ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kicker ; rm -rf common )
@@ -362,14 +360,16 @@
 ( cd opt/kde/share/doc/HTML/es/klines ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kmines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kmines ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/kmplot ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/kmplot ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kmouth ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kmouth ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/knotes ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/knotes ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kpager ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kpaint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kpaint ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kopete ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kopete ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kpilot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kpilot ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kpoker ; rm -rf common )
@@ -380,8 +380,6 @@
 ( cd opt/kde/share/doc/HTML/es/ksnake ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kspell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kspell ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/kstars ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/kstars ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/ktimer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/ktimer ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/ktouch ; rm -rf common )
@@ -398,16 +396,12 @@
 ( cd opt/kde/share/doc/HTML/es/kblackbox ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kcharselect ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/quanta ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/quanta ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kuickshow ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kiconedit ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/klettres ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/klettres ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/kaphorism ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/kaphorism ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kghostview ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kghostview ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/klickety ; rm -rf common )
@@ -418,12 +412,12 @@
 ( cd opt/kde/share/doc/HTML/es/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kenolaba ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kgpgcertmanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kworldclock ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/KRegExpEditor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/ksokoban ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/ksokoban ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kteatime ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kteatime ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kmathtool ; rm -rf common )
@@ -466,8 +460,6 @@
 ( cd opt/kde/share/doc/HTML/es/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kate-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/konqueror ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/konqueror ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/korganizer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/korganizer ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/atlantik ; rm -rf common )
